Coverage for /media/ldata/code/tendril/tendril/utils/pdf.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/utils/pdf.py : 0%

## 20 statements 0 run 20 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 | # Copyright (C) 2015 Chintalagiri Shashank # # This file is part of Tendril. # # This program is free software: you can redistribute it and/or modify # it under the terms of the GNU Affero General Public License as published by # the Free Software Foundation, either version 3 of the License, or # (at your option) any later version. # # This program is distributed in the hope that it will be useful, # but WITHOUT ANY WARRANTY; without even the implied warranty of # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the # GNU Affero General Public License for more details. # # You should have received a copy of the GNU Affero General Public License # along with this program. If not, see <http://www.gnu.org/licenses/>. """ The PDF Utils Module (:mod:`tendril.utils.pdfutils`) ==================================================== This module contains small helper functions to handle PDF files. These functions are independent of the rest of the software and can be reused wherever needed. """ import PyPDF2 import os import subprocess import tendril.dox.wallet def merge_pdf(pdflist, outfilepath, remove_sources=False): """ Merges PDF files. Sources are PDF files whose paths are listed in ``pdflist`` and the combined PDF is written out to ``outfilepath``. :param pdflist: List of paths to PDF files to be merged. :param outfilepath: Path where output PDF file is to be written. :return: outfilepath """ merger = PyPDF2.PdfFileMerger() for f in pdflist: if f is None: continue f = os.path.normpath(f) merger.append(PyPDF2.PdfFileReader(file(f, 'rb'))) merger.write(str(outfilepath)) if remove_sources is True: for f in pdflist: if not tendril.dox.wallet.is_in_wallet(f): os.remove(f) return outfilepath def conv_ps2pdf(pspath, pdfpath): """ Runs `ps2pdf` to convert a PS file specified in ``pspath`` to a PDF file writen out to ``pdfpath``. :param pspath: Path to PS file to be converted. :param pdfpath: Path of PDF file to be generated. """ subprocess.call(['ps2pdf', pspath, pdfpath])